############################################
#    Demonstrate Metropolis                #
#    Algorithm  Using the Beta Dist        #
############################################

alpha<-15
beta<-15
y<-7
n<-24

p<-function(theta) dbeta(theta,alpha+y,n-y+beta)
g<-function(theta) theta^(alpha-1+y)*(1-theta)^(n-y+beta-1)
met<-function(iters,sdev){
   old<-NULL
   count<-0
   old[1]<-1
   for(i in 2:iters){
      old[i]<-old[i-1]
      cand<-rbeta(1,old[i-1],old[i-1])  #can use Metropolis-Hastings for asymetric dist
      r<-g(cand)/g(old[i-1])
      if(runif(1,0,1)<r){
          old[i]<-cand
          count<-count+1
      }
   }
return(list(old=old,count=count))
}

x<-seq(0,1,length=1000)  #these are the theta values.

#Plot p(x)  where the x are the possible theta values.
curve(p(x),0,1,lwd=2)
#Plot g(x)   where the x values are the possible theta values.
curve(g(x),0,1,add=T,lwd=2,col="green")
#curve(g(x),0,1,lwd=2,col="green")



#Now use Metroplis function to get estimate of f(x) from g(x)
metout<-met(10000,1)

#Plot Metropolis estimate of f(x)
lines(density(metout$old),col="blue")

legend(0.65,4,c("Beta(22,32)","Original","Metropolis"),col=c("black","green","blue"),lty=c(1,1,1),lwd=c(2,2,1),bty="n")


a<-15
b<-15

pr<-function(theta) dbeta(theta,a,b)

lines(x,pr(x),lwd=2, col="light gray")

legend(0.65,4,c("Beta(22,32)","Original","Metropolis","Prior Beta(15,15)"),col=c("black","green","blue","light gray"),lty=c(1,1,1),lwd=c(2,2,1),bty="n")






g<-function(theta,mu,sd) dunif(theta,mu,sd)


x<-seq(0,.0000001,length=1000)  #these are the theta values.
plot(x,1/(g(x,0,500)*g(x,0,500)),lwd=2,col="black",ylab="Density",xlab=expression(tau))







g<-function(theta,mu,sd) dnorm(theta,mu,sd)


x<-seq(-100,340,length=1000)  #these are the theta values.
plot(x,g(x,120,100),lwd=2,col="black",ylab="Density",xlab=expression(mu))



