library(R2jags)

setwd("C:\\Users\\mpand\\Documents\\Bayes R Course")


##############################################################
#### Create Initial Values as a funtion       ################
##############################################################


jags.inits<-list(list("mu"=c(0,0),"prec"=c(0.001,0.001)),list("mu"=c(0,0),"prec"=c(0.001,0.001)))


##############################################################
#### Specify the parameters to be monitored   ################
##############################################################

jags.params<-c("mu","prec","diff.mu1.mu2","ratio.var1.var2")

##############################################################
#### Another way to define the data           ################
##############################################################


dat<-list(N1=19,N2=14,a.tmt=c(121,94,119,122,142,168,116,172,155,107,180,119,157,101,145,148,120,147,125),b.tmt=c(126,125,130,130,122,118,118,111,123,126,127,111,112,121))



##############################################################
#### Save and display MCMC results            ################
##############################################################
jagsfit<-jags(data=dat,jags.inits,jags.params,model.file="Code\\sbp.2means.bugs.txt",n.chains=2,n.iter=10000,n.burnin=1000,n.thin=1)
jagsfit

jagsfit$model

jagsfit.mcmc<-as.mcmc(jagsfit)
##############################################################
#### Plots of the MCMC Results                ################
##############################################################
library(mcmcplots)
plot(jagsfit.mcmc)
    
raftery.diag(jagsfit.mcmc)
geweke.diag(jagsfit.mcmc)
gelman.diag(jagsfit.mcmc)
gelman.plot(jagsfit.mcmc)
heidel.diag(jagsfit.mcmc)
autocorr.plot(jagsfit.mcmc)
effectiveSize(jagsfit.mcmc)



#jagsfit<-update(jagsfit,10000)  #only need if diagnostics require
jagsfit




###Produce your own plots

str(jagsfit)     #  Have a look at what has been created
jagsfit$BUGSoutput$sims.matrix  #matrix of the posterior samples
summary(jagsfit$BUGSoutput$sims.matrix)
apply(jagsfit$BUGSoutput$sims.matrix,2,quantile,c(0.025,0.5,0.975))

post.sims<-jagsfit$BUGSoutput$sims.list  #creates a list of the posterior samples

post<-apply(jagsfit$BUGSoutput$sims.matrix,2,density)    # compute posterior densities for visualization
plot(post$diff.mu1.mu2, main=expression(paste("Posterior Plot of: ",mu," diffs")))     #plot posterior of mu


x.point<-0      #a point of interest on thr  x axis
post.area.gtx.point<-sum(ifelse(post.sims$diff.mu1.mu2>x.point,1,0))/length(post.sims$diff.mu1.mu2)   #compute % of draws above x.point
post.area.gtx.point

polygon(c(post$diff.mu1.mu2$x[post$diff.mu1.mu2$x>=x.point], max(post$diff.mu1.mu2$x), x.point), c(post$diff.mu1.mu2$y[post$diff.mu1.mu2$x>=x.point], 0, 0), col="blue")
text(35,0.03,labels=paste("area: ", round(post.area.gtx.point,4)))

