library(R2jags)
library(mcmcplots)

setwd("C:\\Users\\mpand\\Documents\\Bayes R Course")

##############################################################
#### Default settings for the JAGS function   ################
##############################################################

#jags(data, inits, parameters.to.save, model.file="model.bug",
#n.chains=3, n.iter=2000, n.burnin=floor(n.iter/2),
#n.thin=max(1, floor((n.iter - n.burnin) / 1000)),
#DIC=TRUE, working.directory=NULL, jags.seed = 123,
#refresh = n.iter/50, progress.bar = "text", digits=5,
#RNGname = c("Wichmann-Hill", "Marsaglia-Multicarry",
#"Super-Duper", "Mersenne-Twister"),
#jags.module = c("glm","dic")
#)

##############################################################
#### Create Initial Values as a funtion       ################
##############################################################


jags.inits<-function(){list("mu"=50,sd=20)}


##############################################################
#### Specify the parameters to be monitored   ################
##############################################################

jags.params<-c("mu","sd")

##############################################################
#### Save and display MCMC results            ################
##############################################################

jagsfit<-jags("Data\\sbp.data.txt",jags.inits,jags.params,model.file="Code\\sbp.bugs.txt",n.chains=3,n.iter=10000,n.thin=1,n.burnin=1000)
jagsfit

##############################################################
#### Plots of the MCMC Results                ################
##############################################################

plot(jagsfit)
traceplot(jagsfit)     #need to click on the output window to cycle through the plots

jagsfit.mcmc<-as.mcmc(jagsfit)
##############################################################
#### Plots of the MCMC Results                ################
##############################################################

plot(jagsfit.mcmc)

raftery.diag(jagsfit.mcmc)
geweke.diag(jagsfit.mcmc)
gelman.diag(jagsfit.mcmc)
gelman.plot(jagsfit.mcmc)
heidel.diag(jagsfit.mcmc)
autocorr.plot(jagsfit.mcmc)
effectiveSize(jagsfit.mcmc)



#jagsfit<-update(jagsfit,10000)  #only need if diagnostics require
jagsfit

str(jagsfit)



###Produce your own plots

str(jagsfit)     #  Have a look at what has been created
jagsfit$BUGSoutput$sims.matrix  #matrix of the posterior samples
summary(jagsfit$BUGSoutput$sims.matrix)
apply(jagsfit$BUGSoutput$sims.matrix,2,quantile,c(0.025,0.5,0.975))

post.sims<-jagsfit$BUGSoutput$sims.list  #creates a list of the posterior samples

post<-apply(jagsfit$BUGSoutput$sims.matrix,2,density)    # compute posterior densities for visualization
plot(post$sd, main=expression(paste("Posterior Plot of: ",sigma)))  #plot posterior of sd
plot(post$mu, main=expression(paste("Posterior Plot of: ",mu)))     #plot posterior of mu



x.point<-140       #a point of interest on thr  x axis
post.area.gtx.point<-sum(ifelse(post.sims$mu>x.point,1,0))/length(post.sims$mu)   #compute % of draws above x.point
post.area.gtx.point

polygon(c(post$mu$x[post$mu$x>=x.point], max(post$mu$x), x.point), c(post$mu$y[post$mu$x>=x.point], 0, 0), col="blue")
text(155,0.03,labels=paste("area: ", round(post.area.gtx.point,4)))
