library(R2jags)

setwd("C:\\Users\\mpand\\Documents\\Bayes R Course")


##############################################################
#### Create Initial Values as a funtion       ################
##############################################################


jags.inits<-list(list("theta"=.50))


##############################################################
#### Specify the parameters to be monitored   ################
##############################################################

jags.params<-c("theta")


##############################################################
#### Save and display MCMC results            ################
##############################################################
jagsfit<-jags(data="Data\\dvt.data.txt",jags.inits,jags.params,model.file="Code\\dvt.bugs.txt",n.chains=1,n.iter=10000,n.burnin=1000,n.thin=1)
jagsfit
jagsfit$BUGSoutput$summary

jagsfit.mcmc<-as.mcmc(jagsfit)
##############################################################
#### Plots of the MCMC Results                ################
##############################################################
library(mcmcplots)
plot(jagsfit.mcmc)


###Produce your own plots

str(jagsfit)     #  Have a look at what has been created
jagsfit$BUGSoutput$sims.matrix  #matrix of the posterior samples
summary(jagsfit$BUGSoutput$sims.matrix)
apply(jagsfit$BUGSoutput$sims.matrix,2,quantile,c(0.025,0.5,0.975))

post.sims<-jagsfit$BUGSoutput$sims.list  #creates a list of the posterior samples

post<-apply(jagsfit$BUGSoutput$sims.matrix,2,density)    # compute posterior densities for visualization

plot(post$theta, main=expression(paste("Posterior Plot of: ",theta)))     #plot posterior of theta



x.point<-0.10      #a point of interest on thr  x axis
post.area.gtx.point<-sum(ifelse(post.sims$theta>x.point,1,0))/length(post.sims$theta)   #compute % of draws above x.point
post.area.gtx.point

polygon(c(post$theta$x[post$theta$x>=x.point], max(post$theta$x), x.point), c(post$theta$y[post$theta$x>=x.point], 0, 0), col="blue")
text(0.21,6,labels=paste("area: ", round(post.area.gtx.point,4)))
